summaryrefslogtreecommitdiffstats
path: root/ci/deploy.sh
diff options
context:
space:
mode:
authorFeng Pan <fpan@redhat.com>2016-06-13 10:56:26 -0400
committerFeng Pan <fpan@redhat.com>2016-06-13 12:31:52 -0400
commit0002116a82389d00d75bd6954a30775407e3ae37 (patch)
treeae75d83a2a290433ef79475f16bde570cef681b9 /ci/deploy.sh
parentf54ff500424eaf4301dd221a82cb62034c8ed7d9 (diff)
Print undercloud IP after deployment
Change-Id: Ic0828622d129d8acd686d944fff88ed8593227b7 Signed-off-by: Feng Pan <fpan@redhat.com>
Diffstat (limited to 'ci/deploy.sh')
-rwxr-xr-xci/deploy.sh3
1 files changed, 2 insertions, 1 deletions
diff --git a/ci/deploy.sh b/ci/deploy.sh
index 7c07ae63..7de3c7fc 100755
--- a/ci/deploy.sh
+++ b/ci/deploy.sh
@@ -1110,8 +1110,9 @@ fi
EOF
done
# Print out the dashboard URL
source stackrc
+echo "Undercloud IP: $UNDERCLOUD, please connect by doing 'opnfv-util undercloud'"
echo "Overcloud dashboard available at http://\$(heat output-show overcloud PublicVip | sed 's/"//g')/dashboard"
EOI
@@ -1110,8 +1110,9 @@ fi
EOF
done
-# Print out the dashboard URL
+# Print out the undercloud IP and dashboard URL
source stackrc